@@ -108,6 +108,18 @@ static void poly_set(element_ptr dst, element_ptr src)
     }
 }
 
+static int poly_sign(element_ptr f)
+{
+    int res = 0;
+    int i;
+    int n = poly_coeff_count(f);
+    for (i=0; i<n; i++) {
+	res = element_sign(poly_coeff(f, i));
+	if (res) break;
+    }
+    return res;
+}
+
 static void poly_add(element_ptr sum, element_ptr f, element_ptr g)
 {
     int i, n, n1;
@@ -538,6 +550,7 @@ void field_init_poly(field_ptr f, field_ptr base_field)
     f->set_mpz = poly_set_mpz;
     f->out_str = poly_out_str;
     f->set = poly_set;
+    f->sign = poly_sign;
     f->add = poly_add;
     f->is0 = poly_is0;
     f->is1 = poly_is1;
@@ -1029,6 +1042,7 @@ void field_init_polymod(field_ptr f, element_ptr poly)
     f->set_mpz = polymod_set_mpz;
     f->out_str = polymod_out_str;
     f->set = polymod_set;
+    f->sign = poly_sign;
     f->add = polymod_add;
     f->sub = polymod_sub;
     f->neg = polymod_neg;
